Crate display_profile_lib

Crate display_profile_lib 

Provides functions and types to get and set a Windows display profile.

A display Profile contains the resolution, frequency rate, scaling, rotation, etc. for each active display.

Cargo Feature

When the dump feature is active, each Windows CCD API function call also generates a dump-*.json file containing the inputs and outputs of the call.

Structs

Dimensions
Monitor
Position
Rational
Rect

Enums

Error
PixelFormat
Rotation
Scaling
SetProfileAction

Functions

get_profile
Gets the current Windows display profile.
set_profile
Sets the current Windows display profile.

Type Aliases

Profile
Result