docs.rs failed to build display-profile-lib-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
display-profile-lib-0.1.1
Provides functions and types to get and set a Windows display profile.
A display [Profile] contains the resolution, frequency rate, scaling, rotation, etc. for
each active display.
Cargo Feature
When the dump feature is active, each Windows CCD API function call also generates a dump-*.json file containing the inputs and outputs of the call.